==> ejc-assistrmat-api-3.0.0-20220915.064758-213-sources.jar: com/ejianc/business/assist/rmat/enums/BillTypeEnum.java <==
package com.ejianc.business.assist.rmat.enums;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 单据类型编码常量
 */
public enum BillTypeEnum {

    租赁订单("租赁订单", "BT220322000000001"),
    验收单("验收单", "BT220322000000002"),
    启用单("启用单", "BT220322000000006"),
    停用单("停用单", "BT220322000000007"),
    退赔单("退赔单", "BT220322000000004"),
    租出退赔单("租出退赔单", "EJCBT202209000012"),
    遗失单("遗失单", "BT220322000000005"),
    辅料中心租入合同("辅料中心租入合同", "BT220322000000009"),
    辅料中心租入合同变更("辅料中心租入合同变更", "BT220322000000010"),
    辅料中心租入合同记录("辅料中心租入合同记录", "BT220322000000011"),
    租金计算单("租金计算单", "BT220322000000008"),
    辅料中心租入合同解除("辅料中心租入合同解除", "BT220322000000012"),
    辅料中心租入合同结算单("辅料中心租入合同结算单", "BT220322000000014"),
    辅料中心租出启用单("辅料中心租出启用单", "EJCBT202209000001"),
    辅料中心租出停用单("辅料中心租出停用单", "EJCBT202209000002"),
    ;

    private final String name;
    private final String code;
    private static Map<String, BillTypeEnum> enumMap = new HashMap();

    private BillTypeEnum(String name, String code) {
        this.name = name;
        this.code = code;
    }

    public String getName() {
        return this.name;
    }

    public String getCode() {
        return this.code;
    }

    public static BillTypeEnum getEnumByName(String billTypeName) {
        return (BillTypeEnum)enumMap.get(billTypeName);
    }

    static {
        enumMap = (Map)EnumSet.allOf(BillTypeEnum.class).stream().collect(Collectors.toMap(BillTypeEnum::getName, Function.identity(), (k1, k2) -> {
            return k2;
        }));
    }

}

==> ejc-assistrmat-api-3.0.0-20230518.093212-383-sources.jar: com/ejianc/business/assist/rmat/enums/BillTypeEnum.java <==
package com.ejianc.business.assist.rmat.enums;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 单据类型编码常量
 */
public enum BillTypeEnum {

    租赁订单("租赁订单", "BT220322000000001"),
    验收单("验收单", "BT220322000000002"),
    启用单("启用单", "BT220322000000006"),
    停用单("停用单", "BT220322000000007"),
    退赔单("退赔单", "BT220322000000004"),
    遗失单("遗失单", "BT220322000000005"),
    辅料中心租入合同("辅料中心租入合同", "BT220322000000009"),
    辅料中心租入合同变更("辅料中心租入合同变更", "BT220322000000010"),
    辅料中心租入合同记录("辅料中心租入合同记录", "BT220322000000011"),
    租金计算单("租金计算单", "BT220322000000008"),
    辅料中心租入合同解除("辅料中心租入合同解除", "BT220322000000012"),
    辅料中心租入合同结算单("辅料中心租入合同结算单", "BT220322000000014"),

    /* 租出单据类型*/
    租出出库单("租出验收单", "EJCBT202209000015"),
    辅料中心租出启用单("辅料中心租出启用单", "EJCBT202209000001"),
    辅料中心租出停用单("辅料中心租出停用单", "EJCBT202209000002"),
    租出退赔单("租出退赔单", "EJCBT202209000012"),
    租出遗失单("租出遗失单", "EJCBT202209000010"),
    租出租金计算单("租出租金计算单", "EJCBT202210000018"),
    ;

    private final String name;
    private final String code;
    private static Map<String, BillTypeEnum> enumMap = new HashMap();

    private BillTypeEnum(String name, String code) {
        this.name = name;
        this.code = code;
    }

    public String getName() {
        return this.name;
    }

    public String getCode() {
        return this.code;
    }

    public static BillTypeEnum getEnumByName(String billTypeName) {
        return (BillTypeEnum)enumMap.get(billTypeName);
    }

    static {
        enumMap = (Map)EnumSet.allOf(BillTypeEnum.class).stream().collect(Collectors.toMap(BillTypeEnum::getName, Function.identity(), (k1, k2) -> {
            return k2;
        }));
    }

}
